Coverage for /Users/sebastiana/Documents/Sugarpills/confidence/spotify_confidence/__init__.py: 100%

1# Copyright 2017-2020 Spotify AB

2#

3# Licensed under the Apache License, Version 2.0 (the "License");

4# you may not use this file except in compliance with the License.

5# You may obtain a copy of the License at

6#

7# http://www.apache.org/licenses/LICENSE-2.0

8#

9# Unless required by applicable law or agreed to in writing, software

10# distributed under the License is distributed on an "AS IS" BASIS,

11# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.

12# See the License for the specific language governing permissions and

13# limitations under the License.

14

15 from pkg_resources import require as _require

16 from .analysis.bayesian.bayesian_models import BetaBinomial

17 from spotify_confidence.analysis.frequentist.chi_squared import ChiSquared

18 from spotify_confidence.analysis.frequentist.t_test import StudentsTTest

19 from spotify_confidence.analysis.frequentist.z_test import ZTest

20 from spotify_confidence.analysis.frequentist.z_test_linreg import ZTestLinreg

21 from spotify_confidence.analysis.frequentist.experiment import Experiment

22 from spotify_confidence.analysis.frequentist.sample_size_calculator import SampleSizeCalculator

23 from .samplesize.sample_size_calculator import SampleSize

24

25 from . import examples

26 from .options import options

27

28 __version__ = _require("spotify_confidence")[0].version

29

30 __all__ = [

31 "BetaBinomial",

32 "ChiSquared",

33 "StudentsTTest",

34 "ZTest",

35 "ZTestLinreg",

36 "Experiment",

37 "SampleSizeCalculator",

38 "examples",

39 "options",

40 "SampleSize",

41]